# Changelog

:material-history: All notable changes to releasio.

---

## View Changelog

The complete changelog is maintained in the repository:

[:octicons-mark-github-16: View CHANGELOG.md on GitHub](https://github.com/mikeleppane/releasio/blob/main/CHANGELOG.md){ .md-button .md-button--primary }

---

## Release Notes

Release notes for each version are also available on the [GitHub Releases](https://github.com/mikeleppane/releasio/releases) page, which includes:

- Version highlights
- Download links
- Full changelog for each release
